/*---[ logread.h ]----------------------------------------------------
 * Copyright (C) 2000 Tomas Junnonen (majix@sci.fi)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Functions for reading from the syslog file
 *--------------------------------------------------------------------*/

#ifndef _FIRESTARTER_LOGREAD
#define _FIRESTARTER_LOGREAD

#include <config.h>
#include <gnome.h>

void open_logfile (char *logpath);

#endif
